%define lib_major	2
%define lib_name_orig	%{package_prefix}%mklibname binutils
%define lib_name	%{lib_name_orig}%{lib_major}
%define	dev_name	%mklibname binutils -d

%define rpm_ver		2.43.1
%define tar_ver		2.43.1
%define rel		2

# Define if building a cross-binutils
%define build_cross	0
%{expand: %{?cross:	%%global build_cross 1}}

%if %{build_cross}
%define target_cpu	%{cross}
%define target_platform	%{target_cpu}-%_real_vendor-linux%{gnuext}
%define program_prefix	%{target_platform}-
%define package_prefix	cross-%{target_cpu}-
%else
%ifarch armv7hl
%define _host_cpu       armv7hl
%define _gnu		-gnueabi
%endif
%define target_cpu	%{_target_cpu}
%define target_platform	%{_target_platform}
%define program_prefix	%{nil}
%define package_prefix	%{nil}
%endif

%if %{build_cross}
%ifarch %arm
%define gnuext		-gnueabi
%else
%define gnuext		-gnu
%endif
%endif

# List of targets where gold can be enabled
%define gold_arches %{ix86} x86_64 %{arm} aarch64

Summary:	GNU Binary Utility Development Utilities
Name:		%{package_prefix}binutils
Epoch:		1
Version:	%{rpm_ver}
Release:	%mkrel %{rel}
License:	GPLv3+
Group:		Development/Other
URL:		https://www.gnu.org/software/binutils/
Source0:	https://ftp.gnu.org/gnu/binutils/binutils-%{tar_ver}.tar.xz
Source1:	build_cross_binutils.sh
Source2:	binutils-2.19.50.0.1-output-format.sed
Source3:	binutils-git.sh
%if "%{name}" == "binutils"
Provides:	%{lib_name} = %{epoch}:%{version}-%{release}
%endif
# (wally) force build with gcc 14
BuildRequires:	gcc >= 14.0.1-0.20240317.1
# (wally) force binutils 2.42
BuildRequires:	binutils >= 1:2.42
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gettext
BuildRequires:	texinfo-tex
BuildRequires:	dejagnu
BuildRequires:	pkgconfig(zlib)
# make check'ing requires libdl.a
BuildRequires:	glibc-static-devel
# gold make check'ing requires libstdc++.a
BuildRequires:	libstdc++-static-devel

# revert devel enabling on branch
Source101:	binutils-disable-development.patch

# upstream master branch from 200

# patches once liberated from Fedora:
# NOTE! Do not add more without maintainer approval
Patch301:	binutils-2.20.51.0.2-libtool-lib64.patch
Patch302:	binutils-2.37-export-demangle.h.patch
Patch303:	binutils-2.22.52.0.4-no-config-h-check.patch

# Mageia patches
Source401:	binutils-2.39-linux32.patch
Patch402:	binutils-2.42-skip-gold-check.patch

%description
Binutils is a collection of binary utilities, including:

   * ar: creating modifying and extracting from archives
   * nm: for listing symbols from object files
   * objcopy: for copying and translating object files
   * objdump: for displaying information from object files
   * ranlib: for generating an index for the contents of an archive
   * size: for listing the section sizes of an object or archive file
   * strings: for listing printable strings from files
   * strip: for discarding symbols (a filter for demangling encoded C++ symbols
   * addr2line: for converting addresses to file and line
   * nlmconv: for converting object code into an NLM

Install binutils if you need to perform any of these types of actions on
binary files.  Most programmers will want to install binutils.

%package -n	%{dev_name}
Summary:	Main library for %{name}
Group:		Development/Other
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	%{lib_name}-devel = %{epoch}:%{version}-%{release}
Requires:	zlib-devel
# filter out self-requries
%global __requires_exclude ^devel\\(libbfd-%{version}

%description -n	%{dev_name}
This package contains BFD and opcodes static libraries and associated
header files.  Only *.a libraries are included, because BFD doesn't
have a stable ABI.  Developers starting new projects are strongly encouraged
to consider using libelf instead of BFD.

%prep
%setup -q -n binutils-%{tar_ver}
%autopatch -p1
# remove to force regenerating it because of reverts in P10-P12
rm -f ld/ldlex.c

%build
# Additional targets
ADDITIONAL_TARGETS=""
case %{target_cpu} in
i*86 | athlon*)
  ADDITIONAL_TARGETS="x86_64-%{_target_vendor}-%{_target_os}"
  ;;
esac
if [[ -n "$ADDITIONAL_TARGETS" ]]; then
  TARGET_CONFIG="$TARGET_CONFIG --enable-targets=$ADDITIONAL_TARGETS"
fi

case %{target_cpu} in
i*86 | athlon* | aarch64*)
  TARGET_CONFIG="$TARGET_CONFIG --enable-64-bit-bfd"
  ;;
esac

case %{target_cpu} in x86_64*|i?86*|arm*|aarch64*)
  TARGET_CONFIG="$TARGET_CONFIG --enable-targets=x86_64-pep"
  ;;
esac

%if "%{name}" != "binutils"
%define _program_prefix %{program_prefix}
TARGET_CONFIG="$TARGET_CONFIG --target=%{target_platform}"
%endif

# Don't build shared libraries in cross binutils
%if "%{name}" == "binutils"
TARGET_CONFIG="$TARGET_CONFIG --enable-shared --with-pic"
%endif

# Binutils comes with its own custom libtool
# [gb] FIXME: but system libtool also works and has relink fix
%define __libtoolize /bin/true

# Build main binaries
rm -rf objs
mkdir objs
pushd objs
CONFIGURE_TOP=.. %configure $TARGET_CONFIG	--with-bugurl=https://bugs.mageia.org/ \
						--enable-gold \
						--enable-plugins \
						--enable-compressed-debug-sections=none \
						--enable-gprofng=no \
						--enable-relro=yes \
						--enable-new-dtags --disable-rpath \
						--with-system-zlib \
# There seems to be some problems with builds of gold randomly failing whenever
# going through the build system, so let's try workaround this by trying to do
# make once again when it happens...
%make_build tooldir=%{_prefix} || make tooldir=%{_prefix}
popd

%check
# All Tests must pass on x86 and x86_64
# rtp: some ld-arm tests are failing.
# they're fixed in 2.21 but didn't find the fixes
echo ====================TESTING=========================
%ifarch %{ix86} x86_64
%make_build -C objs check LDFLAGS="" || :
# random build failures with gold seems to happen during check as well...
make -k -C objs gold-check LDFLAGS="" || :
%else
%make_build -C objs -k check LDFLAGS="" || :
%endif
echo ====================TESTING END=====================

logfile="%{name}-%{version}-%{release}.log"
rm -f $logfile; find . -name "*.sum" | xargs cat >> $logfile

%install
# disable 'check-rpaths' only from warning about standard RPATHs (0x0001)
# (tmb) TODO / FIXME  better ???
export QA_RPATHS=0x0001


mkdir -p $RPM_BUILD_ROOT%{_prefix}
%make_install -C objs

rm -f $RPM_BUILD_ROOT%{_mandir}/man1/{dlltool,nlmconv,windres}*
rm -f $RPM_BUILD_ROOT%{_infodir}/dir
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/lib{bfd,opcodes}.so

%if "%{name}" == "binutils"
make -C objs prefix=$RPM_BUILD_ROOT%{_prefix} infodir=$RPM_BUILD_ROOT%{_infodir} install-info
install -m 644 include/libiberty.h $RPM_BUILD_ROOT%{_includedir}/
# Ship with the PIC libiberty
install -m 644 objs/libiberty/pic/libiberty.a $RPM_BUILD_ROOT%{_libdir}/
rm -rf $RPM_BUILD_ROOT%{_prefix}/%{_target_platform}/

# Sanity check --enable-64-bit-bfd really works.
%ifarch %{ix86}
grep '^#define BFD_ARCH_SIZE 64$' %{buildroot}%{_prefix}/include/bfd.h
%endif

# Fix multilib conflicts of generated values by __WORDSIZE-based expressions.
%ifarch %{ix86} x86_64
sed -i -e '/^#include "ansidecl.h"/{p;s~^.*$~#include <bits/wordsize.h>~;}' \
    -e 's/^#define BFD_DEFAULT_TARGET_SIZE \(32\|64\) *$/#define BFD_DEFAULT_TARGET_SIZE __WORDSIZE/' \
    -e 's/^#define BFD_HOST_64BIT_LONG [01] *$/#define BFD_HOST_64BIT_LONG (__WORDSIZE == 64)/' \
    -e 's/^#define BFD_HOST_64_BIT \(long \)\?long *$/#if __WORDSIZE == 32\
#define BFD_HOST_64_BIT long long\
#else\
#define BFD_HOST_64_BIT long\
#endif/' \
    -e 's/^#define BFD_HOST_U_64_BIT unsigned \(long \)\?long *$/#define BFD_HOST_U_64_BIT unsigned BFD_HOST_64_BIT/' \
    %{buildroot}%{_prefix}/include/bfd.h
%endif
touch -r bfd/bfd-in2.h %{buildroot}%{_prefix}/include/bfd.h

# Generate .so linker scripts for dependencies; imported from glibc/Makerules:

# This fragment of linker script gives the OUTPUT_FORMAT statement
# for the configuration we are building.
OUTPUT_FORMAT="\
/* Ensure this .so library will not be used by a link for a different format
   on a multi-architecture system.  */
$(gcc $CFLAGS $LDFLAGS -shared -x c /dev/null -o /dev/null -Wl,--verbose -v 2>&1 | sed -n -f "%{SOURCE2}")"

tee %{buildroot}%{_libdir}/libbfd.so <<EOH
/* GNU ld script */

$OUTPUT_FORMAT

/* The libz dependency is unexpected by legacy build scripts.  */
/* The libdl dependency is for plugin support.  (RHBZ 889134)  */
INPUT ( %{_libdir}/libbfd.a %{_libdir}/libsframe.a -liberty -lz -ldl )
EOH

tee %{buildroot}%{_libdir}/libopcodes.so <<EOH
/* GNU ld script */

$OUTPUT_FORMAT

INPUT ( %{_libdir}/libopcodes.a -lbfd -lz )
EOH

%else
rm -f  $RPM_BUILD_ROOT%{_libdir}/libiberty.a
rm -rf $RPM_BUILD_ROOT%{_infodir}
rm -rf $RPM_BUILD_ROOT%{_datadir}/locale/
rm -f  $RPM_BUILD_ROOT%{_prefix}/%{_target_platform}/%{target_cpu}-linux/lib/*.la
%endif

%find_lang binutils
%find_lang gas
%find_lang ld
%find_lang gold
%find_lang gprof
cat gas.lang >> binutils.lang
cat ld.lang >> binutils.lang
cat gold.lang>> binutils.lang
cat gprof.lang >> binutils.lang

%find_lang opcodes
%find_lang bfd
cat opcodes.lang >> binutils.lang
cat bfd.lang >> binutils.lang

%files -f binutils.lang
%{_bindir}/%{program_prefix}addr2line
%{_bindir}/%{program_prefix}ar
%{_bindir}/%{program_prefix}as
%{_bindir}/%{program_prefix}c++filt
%{_bindir}/%{program_prefix}dwp
%{_bindir}/%{program_prefix}elfedit
%{_bindir}/%{program_prefix}gprof
%{_bindir}/%{program_prefix}ld
%{_bindir}/%{program_prefix}ld.bfd
%ifarch %{gold_arches}
%{_bindir}/%{program_prefix}ld.gold
%endif
%{_bindir}/%{program_prefix}nm
%{_bindir}/%{program_prefix}objcopy
%{_bindir}/%{program_prefix}objdump
%{_bindir}/%{program_prefix}ranlib
%{_bindir}/%{program_prefix}readelf
%{_bindir}/%{program_prefix}size
%{_bindir}/%{program_prefix}strings
%{_bindir}/%{program_prefix}strip
%{_mandir}/man1/*
%if "%{name}" == "binutils"
%{_infodir}/*info*
%{_libdir}/bfd-plugins/libdep.so
%{_libdir}/libbfd-%{version}*.so
%{_libdir}/libctf.so.0{,.*}
%{_libdir}/libctf-nobfd.so.0{,.*}
%{_libdir}/libopcodes-%{version}*.so
%{_libdir}/libsframe.so.1{,.*}
%else
%{_prefix}/%{target_platform}/bin/*
%{_prefix}/%{target_platform}/lib/ldscripts
%endif

%if "%{name}" == "binutils"
%files -n %{dev_name}
%{_includedir}/*.h
%{_libdir}/libbfd.a
%{_libdir}/libbfd.so
%{_libdir}/libctf.a
%{_libdir}/libctf.so
%{_libdir}/libctf-nobfd.a
%{_libdir}/libctf-nobfd.so
%{_libdir}/libiberty.a
%{_libdir}/libopcodes.a
%{_libdir}/libopcodes.so
%{_libdir}/libsframe.a
%{_libdir}/libsframe.so
%endif


%changelog
* Thu Dec 12 2024 ghibo <ghibo> 1:2.43.1-2.mga10
+ Revision: 2123665
- Add libsframe.a to fake libbfd.so to avoid missed symbols during bfd detection (required for kernel), RHBZ#2174841

* Fri Oct 25 2024 wally <wally> 1:2.43.1-1.mga10
+ Revision: 2111199
- new version 2.43.1

* Tue Oct 15 2024 wally <wally> 1:2.43-1.mga10
+ Revision: 2107109
- new version 2.43

* Mon Apr 08 2024 wally <wally> 1:2.42-10.mga10
+ Revision: 2056016
- basesystem rebuild for i686

* Sat Mar 23 2024 wally <wally> 1:2.42-9.mga10
+ Revision: 2051625
- rebuild with gcc 14.0.1 20240317 snapshot

* Wed Mar 13 2024 wally <wally> 1:2.42-8.mga10
+ Revision: 2049740
- rebuild with downgraded gcc 13.2.0

* Thu Mar 07 2024 wally <wally> 1:2.42-7.mga10
+ Revision: 2048437
- rebuild with gcc-14.0.1-0.20240303.1

* Sat Mar 02 2024 wally <wally> 1:2.42-6.mga10
+ Revision: 2047180
- set DT_RUNPATH instead of DT_RPATH by default (--enable-new-dtags)
- build with system zlib

* Fri Mar 01 2024 wally <wally> 1:2.42-5.mga10
+ Revision: 2046176
- rebuild with gcc 14.0.1 20240225

* Wed Feb 28 2024 wally <wally> 1:2.42-4.mga10
+ Revision: 2045476
- rebuild with fixed toolchain triplets

* Wed Feb 28 2024 wally <wally> 1:2.42-3.mga10
+ Revision: 2044858
- fix armv7hl target platform

* Tue Feb 27 2024 wally <wally> 1:2.42-2.mga10
+ Revision: 2044830
- fix arm32 build

* Tue Feb 27 2024 wally <wally> 1:2.42-1.mga10
+ Revision: 2044825
- new version 2.42

* Tue Jun 27 2023 tmb <tmb> 1:2.40-11.mga9
+ Revision: 1963219
- Fix an illegal memory access when an accessing a zero-length
  verdef table (CVE-2023-1972)

* Mon May 08 2023 tmb <tmb> 1:2.40-10.mga9
+ Revision: 1956237
- Updated Hungarian translation for the gprof directory
- New Georgian translation for the bfd sub-directory

* Tue Apr 11 2023 tmb <tmb> 1:2.40-9.mga9
+ Revision: 1952764
- lto: Don't add indirect symbols for versioned aliases in IR (PR ld/30281)

* Sat Apr 08 2023 tmb <tmb> 1:2.40-8.mga9
+ Revision: 1951802
- gas: arm: Fix a further IT-predicated vcvt issue in the presense
  of MVE vcvtn
- gas: arm: Change warning message to not reference specific
  A-class architecture revision

* Sat Mar 25 2023 tmb <tmb> 1:2.40-7.mga9
+ Revision: 1950363
- PR30217, dynamic relocations using local dynamic symbols
- coff_get_normalized_symtab bfd_release
- libctf: fix assertion failure with no system qsort_r
- libctf: get the offsets of fields of unnamed structs/unions right

* Mon Mar 06 2023 tmb <tmb> 1:2.40-6.mga9
+ Revision: 1947942
- PR30198, Assertion and segfault when linking x86_64 elf and coff

* Sat Mar 04 2023 tmb <tmb> 1:2.40-5.mga9
+ Revision: 1947574
- Updated translations for the bfd and gprof directories.
- Updated Serbian translations for gold, gprof and opcodes sub-directories
- ppc32 and "LOAD segment with RWX permissions"
- PR30046, power cmpi leads to unknown architecture
- PR30155, ld segfault in _bfd_nearby_section

* Tue Feb 14 2023 tmb <tmb> 1:2.40-4.mga9
+ Revision: 1942401
- gas: correct symbol name comparison in .startof./.sizeof. handling

* Fri Feb 10 2023 tmb <tmb> 1:2.40-3.mga9
+ Revision: 1940078
- Updated Swedish translation for the binutils sub-directory
- bpf: fix error conversion from long unsigned int to unsigned int [-Werror=overflow]
- Pass JANSSON_LIBS and ZSTD_LIBS to ld-bootstrap/bootrap.exp
- configure: remove dependencies on gmp and mpfr when gdb is disabled

* Sat Jan 28 2023 tmb <tmb> 1:2.40-2.mga9
+ Revision: 1936697
- Updated Swedish translation for the binutils sub-directory
- gprofng: PR29521 [docs] man pages are not in the release tarball
- gprofng: PR30043 libgprofng.so.* are installed to a wrong location

* Sat Jan 21 2023 tmb <tmb> 1:2.40-1.mga9
+ Revision: 1934671
- update to 2.40
  * drop merged/obsolete patches
- Updated translations for the gas and binutils sub-directories
- libctf: update regexp to allow makeinfo to build document
- Fix version number snafu in some configuration files: 2.40.00 should be 2.40
- toplevel: Makefile.def: add install-strip dependency on libsframe

* Thu Jan 12 2023 tmb <tmb> 1:2.39-6.mga9
+ Revision: 1932687
- ld/testsuite: Adjust for ELF_MAXPAGESIZE 0x1000
- ARM: Fix ld bloat introduced between binutils-2.38 and 2.39

* Thu Jan 05 2023 tmb <tmb> 1:2.39-5.mga9
+ Revision: 1930502
- x86-64: Allocate input section memory if needed [BZ #29939]

* Sat Nov 19 2022 tmb <tmb> 1:2.39-4.mga9
+ Revision: 1908773
- arm: Use DWARF numbering convention for pseudo-register representation

* Sun Nov 06 2022 tmb <tmb> 1:2.39-3.mga9
+ Revision: 1903913
- strip: heap-buffer-overflow [PR #29482] (CVE-2022-38533)

* Thu Sep 22 2022 tmb <tmb> 1:2.39-2.mga9
+ Revision: 1891704
- elf: Reset alignment for each PT_LOAD segment [BZ #29435]

* Sat Sep 17 2022 tmb <tmb> 1:2.39-1.mga9
+ Revision: 1889574
- PR 29466: testsuite/config/default.exp (SIZE): Adjust relative path

* Sat Aug 13 2022 tmb <tmb> 1:2.39-0.3.mga9
+ Revision: 1877262
- disable gprofng for now
- ld: fix NEWS typos
- gas/Dwarf: properly skip zero-size functions
- PR29462, internal error in relocate, at powerpc.cc:10796
- PR29466, APP/NO_APP with .linefile
- rebase linux32 and gold-check patches
- update filelists
- update to 2.39
  * drop merged patches

* Sun Jul 24 2022 tmb <tmb> 1:2.38-14.mga9
+ Revision: 1870843
- libctf: fix linking together multiple objects derived from the same source
- libctf: tests: prune warnings from compiler output
- x86: Properly check invalid relocation against protected symbol
- i386: Don't allow GOTOFF relocation against IFUNC symbol for PIC

* Wed Jun 01 2022 tmb <tmb> 1:2.38-12.mga9
+ Revision: 1861033
- x86: Properly handle IFUNC function pointer reference (PR ld/29216)

* Fri May 20 2022 tmb <tmb> 1:2.38-10.mga9
+ Revision: 1859480
- AArch64: Enable FP16 by default for Armv9-A

* Sat May 14 2022 tmb <tmb> 1:2.38-9.mga9
+ Revision: 1858058
- Adjust ld ctf test for 32-bit targets
- PR29142, segv in ar with empty archive and libdeps specified

* Fri May 06 2022 tmb <tmb> 1:2.38-8.mga9
+ Revision: 1856538
- rebuild with gcc 12.1.0 final

* Thu Apr 28 2022 tmb <tmb> 1:2.38-7.mga9
+ Revision: 1854943
- x86: Properly handle function pointer reference

* Fri Mar 25 2022 tmb <tmb> 1:2.38-6.mga9
+ Revision: 1826232
- Updated Serbian (for binutils/) and Russian (for gprof/) translations
- dlltool: Use the output name as basis for deterministic temp prefixes [BZ #28885]
- libctf, ld: diagnose corrupted CTF header cth_strlen [BZ #28933]

* Fri Mar 18 2022 umeabot <umeabot> 1:2.38-5.mga9
+ Revision: 1797679
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 tmb <tmb> 1:2.38-4.mga9
+ Revision: 1788149
- rebuild with gcc 12

* Wed Mar 02 2022 tmb <tmb> 1:2.38-3.mga9
+ Revision: 1787809
- Revert "Check thin archive element file size against archive header"

* Sat Feb 19 2022 tmb <tmb> 1:2.38-2.mga9
+ Revision: 1781422
- PR28763: SIGSEGV during processing of program headers via readelf
- PR28862: heap-buffer-overflow in parse_stab_string

* Thu Feb 17 2022 tmb <tmb> 1:2.38-1.mga9
+ Revision: 1779462
- x86: Disallow invalid relocation against protected symbol
- PR28882: build failure with gcc-4.2 due to use of 0b literals
- i386: Update I386_NEED_DYNAMIC_RELOC_TYPE_P for DT_TEXTREL
- ld: Keep indirect symbol from IR if referenced from shared object
- Updated Serbian translations for the bfd, gold, ld and opcodes directories
- update to 2.38
  * drop merged patches

* Sun Jan 16 2022 tmb <tmb> 1:2.37-22.mga9
+ Revision: 1768665
- fix a stack exhaustion bug parsing malicious STABS format debug
  information [PR #28718]
- fix -Waddress warning in ldelf.c

* Mon Nov 15 2021 tmb <tmb> 1:2.37-19.mga9
+ Revision: 1757007
- gold: Place .note.gnu.property section before other note sections

* Fri Nov 05 2021 tmb <tmb> 1:2.37-18.mga9
+ Revision: 1753991
- PR28540, segmentation fault on NULL byte_get

* Fri Oct 22 2021 tmb <tmb> 1:2.37-17.mga9
+ Revision: 1752678
- PR28417, std::string no longer allows accepting nullptr_t

* Mon Oct 18 2021 tmb <tmb> 1:2.37-16.mga9
+ Revision: 1752057
- PR28459, readelf issues bogus warning

* Thu Oct 07 2021 tmb <tmb> 1:2.37-15.mga9
+ Revision: 1749960
- PR28422, build_id use-after-free

* Sat Oct 02 2021 tmb <tmb> 1:2.37-14.mga9
+ Revision: 1747341
- rebuild for glibc 2.34

* Fri Oct 01 2021 tmb <tmb> 1:2.37-13.mga9
+ Revision: 1747282
- ld: pru: Fix resource_table output section alignment

* Tue Sep 28 2021 tmb <tmb> 1:2.37-12.mga9
+ Revision: 1746802
- rebuild with glibc 2.34

* Tue Sep 28 2021 tmb <tmb> 1:2.37-11.mga9
+ Revision: 1746798
- PR28391, strip/objcopy --preserve-dates *.a: cannot set time

* Fri Sep 17 2021 tmb <tmb> 1:2.37-10.mga9
+ Revision: 1745657
- disable 'check-rpaths' from warning about standard RPATHs (0x0001)

* Thu Sep 16 2021 tmb <tmb> 1:2.37-9.mga9
+ Revision: 1745617
- fix up broken fedora 'filename-in-error-messages' patch (mga#29465)

* Wed Sep 01 2021 tmb <tmb> 1:2.37-8.mga9
+ Revision: 1743961
- PR28250, Null pointer dereference in debug_class_type_samep

* Sat Aug 28 2021 tmb <tmb> 1:2.37-7.mga9
+ Revision: 1743309
- PR28264, ld.bfd crash on linking efivar with LTO

* Wed Aug 11 2021 tmb <tmb> 1:2.37-6.mga9
+ Revision: 1741096
- remove ld/ldlex.c to force it to get properly re-genenrated because of ld script parsing reverts
- fix ld script parsing regression [PR #28217]
  * Revert "Re: ld script expression parsing"
  * Revert "ld --defsym"
  * Revert "ld script expression parsing"

* Sat Aug 07 2021 tmb <tmb> 1:2.37-4.mga9
+ Revision: 1740050
- PR28186, SEGV elf.c:7991:30 in _bfd_elf_fixup_group_sections

* Thu Jul 29 2021 tmb <tmb> 1:2.37-3.mga9
+ Revision: 1738128
- texi2pod.pl: add no-op --no-split option support [PR28144]
- opcodes: constify & local meps macros
- bfd: Close the file descriptor if there is no archive fd

* Sat Jul 24 2021 tmb <tmb> 1:2.37-2.mga9
+ Revision: 1737625
- libiberty: Change "uint" to "unsigned"
- PR28106, build of 2.37 fails on FreeBSD and Clang
- Updated Russian translation for the bfd library
- ld: fix script expression parsing
- Revert: PowerPC: Don't generate unused section symbols

* Tue Jul 20 2021 tmb <tmb> 1:2.37-1.mga9
+ Revision: 1737162
- rebase P2, P4, P51, P52
- update to 2.37

* Sat Jul 10 2021 tmb <tmb> 1:2.36.1-10.mga9
+ Revision: 1735615
- fix parsing of DWARF fuction and variable tags [BZ #27484]
- fix quadratic slow down in the BFD library [BZ #28058]

* Sun Jul 04 2021 tmb <tmb> 1:2.36.1-9.mga9
+ Revision: 1734663
- arm: don't treat XScale features as part of the FPU [PR 28031]

* Thu Jun 24 2021 tmb <tmb> 1:2.36.1-8.mga9
+ Revision: 1732108
- arm: Fix bugs with MVE vmov from two GPRs to vector lanes
- arm: Fix forward thumb references [PR gas/25235]

* Sun Apr 25 2021 tmb <tmb> 1:2.36.1-7.mga9
+ Revision: 1719607
- Fix type of .persistent.bss section

* Sun Apr 25 2021 tmb <tmb> 1:2.36.1-6.mga9
+ Revision: 1719251
- rebuild with gcc 11.1

* Sun Apr 18 2021 tmb <tmb> 1:2.36.1-4.mga9
+ Revision: 1716730
- AArch64: Fix Atomic LD64/ST64 classification
- AArch64: Fix Diagnostic messaging for LD/ST Exclusive
- Make objcopy -p work when an output file is specified
- drop P8, not from upstream
- clean old stuff
- fix urls

* Wed Mar 24 2021 tmb <tmb> 1:2.36.1-3.mga9
+ Revision: 1708985
- PR libctf/27482: Add install dependencies for ld -> bfd and libctf -> bfd
- PR ld/27587: DWARF: Check version >= 3 for DW_FORM_ref_addr

* Tue Mar 02 2021 tmb <tmb> 1:2.36.1-2.mga9
+ Revision: 1696464
- bfd: PR27441, inconsistency in weak definitions

* Sun Feb 28 2021 tmb <tmb> 1:2.36.1-1.mga9
+ Revision: 1693179
- update to 2.36.1 + current fixes from 2.36 branch

* Sat Jan 30 2021 tmb <tmb> 1:2.35.2-1.mga8
+ Revision: 1674082
- update to 2.35.2
  * drop merged fixes

* Sun Jan 03 2021 tmb <tmb> 1:2.35.1-6.mga8
+ Revision: 1668394
- nm: Remove --with-symbol-versions [PR binutils/26302]
- elf: Keep only one '@' for undefined versioned symbols [PR ld/26382]
- nm -P portable output format regression [PR binutils/27128]

* Wed Dec 09 2020 tmb <tmb> 1:2.35.1-5.mga8
+ Revision: 1654771
- x86-64: Convert load to mov only for GOTPCRELX relocations (PR ld/27016)

* Thu Nov 26 2020 tmb <tmb> 1:2.35.1-4.mga8
+ Revision: 1649544
- asan: readelf: fix stack buffer overflow [PR 26929]

* Sun Nov 22 2020 tmb <tmb> 1:2.35.1-3.mga8
+ Revision: 1648379
- testbuild with glibc 2.32

* Sat Nov 21 2020 tv <tv> 1:2.35.1-2.mga8
+ Revision: 1648212
- Do not create PLT entries for AARCH64 IFUNC symbols referenced in debug sections
- Fix handling of relocations for AArch64 conditional branches
  (and a cople less untested testcases too)
- FC has dropped binutils-do-not-provide-shared-section-symbols.patch & binutils-2.28-ignore-gold-duplicates.patch
  thus unexpected failures go down from 71 to 4

* Fri Nov 20 2020 tmb <tmb> 1:2.35.1-1.mga8
+ Revision: 1648041
- update to 2.35.1 + 2.35 branch fixes as of 2020-11-20

* Mon Nov 16 2020 tmb <tmb> 1:2.34-15.mga8
+ Revision: 1646729
- Fix the ARM assembler to generate a Realtime profile for armv8-r [PR 25992]
- Prevent a potential use-after-fee memory corruption bug in the linker
  (for PE format files) [PR 25993]
- gas: Fix checking for backwards .org with negative offset
- aarch64: set sh_entsize of .plt to 0
- x86: Properly merge -z ibt and -z shstk

* Mon May 18 2020 tmb <tmb> 1:2.34-14.mga8
+ Revision: 1585980
- verify fixed binutils

* Mon May 18 2020 tmb <tmb> 1:2.34-13.mga8
+ Revision: 1585966
- re-enable: gas: Fix tight loop on recursively-defined symbols,
  along with a follow-up fix for missing LOCAL_SYMBOL_CHECK

* Sun May 17 2020 tmb <tmb> 1:2.34-12.mga8
+ Revision: 1585711
- revert: 'gas: Fix tight loop on recursively-defined symbols'

* Sat May 16 2020 tmb <tmb> 1:2.34-11.mga8
+ Revision: 1584734
- gas: Fix tight loop on recursively-defined symbols

* Thu May 07 2020 tmb <tmb> 1:2.34-10.mga8
+ Revision: 1581490
- gas: Fix scalar vmul inside it block when assembling for MVE [PR 25863]

* Tue May 05 2020 tmb <tmb> 1:2.34-9.mga8
+ Revision: 1580445
- Fix dwarf.c build with GCC 10
- Include: Sync lto-symtab.h and plugin-api.h with GCC
- Silence warnings due to plugin API change
- plugin: Use LDPT_ADD_SYMBOLS_V2 to get symbol type
- plugin: Don't invoke LTO-wrapper
- include: Sync lto-symtab.h and plugin-api.h with GCC
- Arm: Fix thumb2 PLT branch offsets
- Arm: Fix LSB of GOT for Thumb2 only PLT
- BFD: Exclude sections with no content from compress check

* Tue Mar 24 2020 tmb <tmb> 1:2.34-7.mga8
+ Revision: 1559516
- bfd: Change num_group to unsigned int

* Fri Mar 20 2020 tmb <tmb> 1:2.34-6.mga8
+ Revision: 1558339
- Import fixes for using the LTO plugin with nm.
- plugin: Call dlclose before return in try_load_plugin
- PR25585, PHDR segment not covered by LOAD segment
- Don't call lto-wrapper for ar and ranlib
- Re: PR24511, nm should not mark symbols in .init_array as "t"
- Adjust PR25355 testcase
- gas, arm: PR25660 Fix vadd/vsub with lt and le condition codes for MVE
- gas, arm: Fix bad backport of PR25660

* Fri Feb 21 2020 umeabot <umeabot> 1:2.34-5.mga8
+ Revision: 1547897
- Mageia 8 Mass Rebuild

* Thu Feb 13 2020 tmb <tmb> 1:2.34-4.mga8
+ Revision: 1513435
- PR 25447: fix a potential illegal memory access when parsing PE binaries

* Mon Feb 10 2020 tmb <tmb> 1:2.34-3.mga8
+ Revision: 1488632
- Mention x86 assembler options to align branches
- aarch64: Fix MOVPRFX markup for bf16 conversions
- x86: Accept Intel64 only instruction by default

* Mon Feb 03 2020 tmb <tmb> 1:2.34-2.mga8
+ Revision: 1486583
- filter out self-requires on devel(libbfd in devel package

* Sun Feb 02 2020 tmb <tmb> 1:2.34-1.mga8
+ Revision: 1486458
- update to 2.34
  * drop merged patch
- update filelists
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 15 2019 tmb <tmb> 1:2.33.1-2.mga8
+ Revision: 1453876
- Arm: Fix out of range conditional branch [PR/24991]

* Sat Oct 12 2019 tmb <tmb> 1:2.33.1-1.mga8
+ Revision: 1452406
- update to 2.33.1
  * drop merges patches

* Sun Sep 08 2019 tmb <tmb> 1:2.32-17.mga8
+ Revision: 1438570
- PR24909, Uninitialized use on stack in readelf
- PR24911, Heap overflow issue in qsort_r, dwarf.c
- [AArch64][gas] Update MTE system register encodings
- AArch64: Fix LD crash on weak and undefined TLS symbols. (PR/24602).
- Arm: Fix performance issue with thumb-2 tailcalls

* Thu Aug 29 2019 tv <tv> 1:2.32-16.mga8
+ Revision: 1435156
- Disable the default generation of compressed debug sections that rpm/dwz
  doesn't like (rhbz#1366182)
  aka solves some rpm testsuite failures due to "DWARF version 0 unhandled"

* Tue Aug 13 2019 tmb <tmb> 1:2.32-15.mga8
+ Revision: 1429119
- rebuild with gcc 9.2

* Sat Aug 03 2019 tmb <tmb> 1:2.32-14.mga8
+ Revision: 1427189
- [AArch64] Add support for GMID_EL1 register for +memtag
- [ARM]: Correct the regular expressions in cmse_main_sec_debug.d file
- getstring: check bounds before using [PR23940]

* Sat Jul 13 2019 tmb <tmb> 1:2.32-12.mga8
+ Revision: 1420993
- aarch64: add STO_AARCH64_VARIANT_PCS and DT_AARCH64_VARIANT_PCS
- aarch64: handle .variant_pcs directive in gas
- aarch64: override default elf .set handling in gas
- aarch64: handle STO_AARCH64_VARIANT_PCS in bfd
- PR24785, bfd crashes on empty .PPC.EMB.apuinfo section
- aarch64: fix DT_AARCH64_VARIANT_PCS handling in readelf

* Fri Jul 05 2019 tmb <tmb> 1:2.32-11.mga8
+ Revision: 1418759
- [AArch64] Fix bogus MOVPRFX warning for GPR form of CPY
- [AArch64] Add missing C_MAX_ELEM flags for SVE conversions
- [AArch64] Allow MOVPRFX to be used with FMOV
- Ensure that debug information for ARM security functions is not
  dropped by the linker when performing garbage collection.

* Sat Jun 29 2019 tmb <tmb> 1:2.32-10.mga8
+ Revision: 1415587
- elf: Remove the property after reporting its removal

* Sun May 26 2019 tmb <tmb> 1:2.32-9.mga7
+ Revision: 1399174
- AArch64: Add SVE DWARF registers
- PR24559: Fix pseudo load-operations for Armv8-M Baseline

* Sat May 18 2019 tmb <tmb> 1:2.32-8.mga7
+ Revision: 1398348
- PR24567, assertion failure in ldlang.c:6868 when compiling with -flto

* Thu May 02 2019 tmb <tmb> 1:2.32-6.mga7
+ Revision: 1396136
- fix CVE-2019-9071/3/4/5/7

* Sat Apr 20 2019 tmb <tmb> 1:2.32-5.mga7
+ Revision: 1393991
- AArch64: Add new LDGM/STGM instruction
- AArch64: Update Store Allocation Tag instructions
- AArch64: When DF_BIND_NOW don't use TLSDESC GOT value
- x86: Also check x86 linker_def for non-shared definition

* Sat Apr 06 2019 tmb <tmb> 1:2.32-4.mga7
+ Revision: 1386358
- AArch64: Fix disassembler bug with out-of-order sections

* Sat Feb 23 2019 tmb <tmb> 1:2.32-3.mga7
+ Revision: 1369548
- rebuild with gcc 8.3.0 final

* Sun Feb 10 2019 tmb <tmb> 1:2.32-2.mga7
+ Revision: 1365102
- x86-64: Restore PIC check for PCREL reloc against protected symbol [BZ #24151]
- gas: Pass max_bytes to TC_FRAG_INIT [BZ #24165]

* Sat Feb 09 2019 tmb <tmb> 1:2.32-1.mga7
+ Revision: 1364365
- Updated Swedish translation for the opcodes sub-director
- Arm: Backport hlt to all architectures

* Tue Feb 05 2019 tmb <tmb> 1:2.32-0.1.mga7
+ Revision: 1363474
- update to 2.32
  * drop merged patches
- rebase demangle and linux32 patches

* Sat Feb 02 2019 luigiwalser <luigiwalser> 1:2.31.1-23.mga7
+ Revision: 1362517
- add patch from fedora to fix CVE-2018-20002

* Sat Dec 15 2018 tmb <tmb> 1:2.31.1-22.mga7
+ Revision: 1341405
- PR23788, objcopy: failed to find link section

* Tue Dec 11 2018 tmb <tmb> 1:2.31.1-20.mga7
+ Revision: 1340286
- x86: Put back BFD_RELOC_X86_64_GOTPCREL

* Sun Dec 02 2018 tmb <tmb> 1:2.31.1-19.mga7
+ Revision: 1337442
- elf: Don't merge .note.gnu.property section in IR [PR ld/23929]

* Wed Nov 28 2018 tmb <tmb> 1:2.31.1-18.mga7
+ Revision: 1336486
- AArch64: Fix regression in Cortex A53 erratum when PIE. (PR ld/23904)

* Wed Nov 07 2018 tmb <tmb> 1:2.31.1-17.mga7
+ Revision: 1328787
- bfd: PR ld/23818: Hide symbols defined in discarded input sections
- PR gas/23854: x86: Disable GOT relaxation with data prefix

* Sat Oct 20 2018 tmb <tmb> 1:2.31.1-16.mga7
+ Revision: 1322966
- Ignore duplicate indirect symbols generated by GOLD

* Fri Oct 19 2018 tmb <tmb> 1:2.31.1-15.mga7
+ Revision: 1322554
- Arm: Skip new binary decode tests on pe targets

* Fri Oct 19 2018 tmb <tmb> 1:2.31.1-14.mga7
+ Revision: 1322450
- Arm: Fix disassembler crashing on -b binary when thumb file and thumb not forced

* Wed Oct 17 2018 tmb <tmb> 1:2.31.1-13.mga7
+ Revision: 1321528
- AArch64: Fix error checking for SIMD udot (by element)

* Sat Oct 13 2018 tmb <tmb> 1:2.31.1-12.mga7
+ Revision: 1320044
- x86: Add Intel ENCLV to assembler and disassembler

* Fri Sep 28 2018 tmb <tmb> 1:2.31.1-11.mga7
+ Revision: 1309743
- fixes from upstream binutils 2.31 branch
  * PR ld/23499:  Always clear h->verinfo.verdef when overriding a
    dynamic definition
  * PR ld/23499: elf: Check for corrupt symbol version info
  * gas: Improve the code in the assembler to detect and reject a
    duplicate input and output file
  * gas: Fix Aarch64 bug in warning filtering

* Thu Sep 13 2018 tv <tv> 1:2.31.1-10.mga7
+ Revision: 1258923
- use new macros
- Add i386pep emulation for all EFI capable CPU types

* Mon Sep 03 2018 tv <tv> 1:2.31.1-8.mga7
+ Revision: 1256426
- rely on filetriggers for info system (mga#23482)

* Tue Aug 28 2018 tmb <tmb> 1:2.31.1-7.mga7
+ Revision: 1255250
- add updates from upstream 2.31 branch:
  * S/390: Set the htm flag on PPA
  * Fix unwind offset for call_info->start_symbol
  * LD, AArch64: Fix ifunc testisms
  * Fix spurious check-ld failures on aarch64-elf
  * Add --warn-drop-version option; by default, do not warn when discarding version info.
  * Updated Bulgarian translation for the ld/ directory
  * PowerPC64 __tls_get_addr_opt stub .eh_frame fix
  * __tls_get_addr_opt stubs and tocsave optimization
  * x32: Align the .note.gnu.property section to 4 bytes
  * x86: Update assembler tests for non-ELF targets
  * x86: Properly merge GNU_PROPERTY_X86_ISA_1_USED
  * x86: Replace evex-no-scale.s with evex-no-scale-[32|64].s
  * x86: Properly add X86_ISA_1_NEEDED property
  * ld-x86-64/pr23486b.d: Swap pr23486a.s and pr23486b.s

* Mon Aug 06 2018 tmb <tmb> 1:2.31.1-6.mga7
+ Revision: 1248420
- gold: Fix type checking errors

* Tue Jul 31 2018 tmb <tmb> 1:2.31.1-5.mga7
+ Revision: 1246318
- x86: don't mistakenly scale non-8-bit displacements [PR gas/23465]

* Sun Jul 29 2018 tmb <tmb> 1:2.31.1-4.mga7
+ Revision: 1245760
- revert PR 23161 as it breaks builds (Fedora, reported by pterjan)

* Sat Jul 28 2018 tmb <tmb> 1:2.31.1-3.mga7
+ Revision: 1245641
- rebuild with gcc 8.2

* Tue Jul 24 2018 tmb <tmb> 1:2.31.1-2.mga7
+ Revision: 1245045
- x86: Split vcvtps2{,u}qq and vcvttps2{,u}qq [PR gas/23418]
- x86: Add a GNU_PROPERTY_X86_ISA_1_USED note if needed [PR ld/23428]

* Sat Jul 21 2018 tmb <tmb> 1:2.31.1-1.mga7
+ Revision: 1244740
- sort Fedora patches
- drop obsolete patches
- drop P5, use configure flag --enable-relro=yes instead
- rebase P51, P52
- use autopatch
- drop obsolete ppc and sparc stuff
- update to 2.31.1

* Sat May 26 2018 tmb <tmb> 1:2.29.1-10.mga7
+ Revision: 1232324
- rebuild for new glibc and optflags

* Mon Apr 30 2018 tmb <tmb> 1:2.29.1-9.mga7
+ Revision: 1224009
- restore fix for PR21074 / Ignore duplicate indirect symbols generated by GOLD
+ wally <wally>
- add aarch64 support

* Thu Jan 18 2018 tmb <tmb> 1:2.29.1-8.mga7
+ Revision: 1194363
- update fixes from 2.29 branch

* Fri Dec 22 2017 tmb <tmb> 1:2.29.1-7.mga7
+ Revision: 1184070
- add more fixes from 2.29 branch

* Mon Dec 04 2017 tmb <tmb> 1:2.29.1-6.mga7
+ Revision: 1181145
- update fixes from 2.29 branch

* Sat Nov 04 2017 tmb <tmb> 1:2.29.1-4.mga7
+ Revision: 1175901
- update fixes from 2.29 branch

* Wed Oct 11 2017 tmb <tmb> 1:2.29.1-3.mga7
+ Revision: 1170877
- add fixes from 2.29 branch

* Thu Sep 21 2017 tmb <tmb> 1:2.29.1-2.mga7
+ Revision: 1156831
- sync up with final 2.29.1 release
- drop some obsolete patches/references

* Fri Sep 15 2017 tmb <tmb> 1:2.29.1-1.mga7
+ Revision: 1154452
- update to 2.29.1

* Mon Sep 11 2017 tmb <tmb> 1:2.29.0-8.mga7
+ Revision: 1152988
- update fixes from 2.29 branch

* Tue Sep 05 2017 tmb <tmb> 1:2.29.0-7.mga7
+ Revision: 1151538
- update fixes from 2.29 branch

* Sat Sep 02 2017 tmb <tmb> 1:2.29.0-6.mga7
+ Revision: 1150574
- more fixes from upstream 2.29 branch

* Fri Sep 01 2017 tmb <tmb> 1:2.29.0-5.mga7
+ Revision: 1150371
- update fixes from 2.29 branch

* Sun Aug 27 2017 tmb <tmb> 1:2.29.0-4.mga7
+ Revision: 1148246
- update fixes from 2.29 branch

* Mon Aug 14 2017 tmb <tmb> 1:2.29.0-3.mga7
+ Revision: 1140267
- update fixes from 2.29 branch

* Sun Aug 13 2017 tmb <tmb> 1:2.29.0-2.mga7
+ Revision: 1140031
- add fixes from upstream 2.29 branch

* Sun Aug 06 2017 tmb <tmb> 1:2.29-0.1.mga7
+ Revision: 1137921
- rebase linux32 and gold check patch
- sync some useful patches with fedora
- drop merged security fixes
- update to 2.29

* Sat Jul 01 2017 akien <akien> 1:2.25.1-7.mga6
+ Revision: 1108880
- Add FSF binutils patch to fix running readelf on debug info binaries (rhbz#1434050)

* Sat Jul 01 2017 tmb <tmb> 1:2.25.1-6.mga6
+ Revision: 1108788
- fix CVE-2016-4487/4488/4489/4490/4492/4493/6131 and CVE-2017-6969/7210
+ neoclust <neoclust>
- Add P1000 - Fixes CVE-2016-2226 (mga#18987)

* Wed Feb 10 2016 umeabot <umeabot> 1:2.25.1-5.mga6
+ Revision: 953250
- Mageia 6 Mass Rebuild

* Thu Aug 20 2015 tmb <tmb> 1:2.25.1-4.mga6
+ Revision: 866990
- rebuild with new gcc

* Thu Aug 20 2015 tmb <tmb> 1:2.25.1-3.mga6
+ Revision: 866658
- rebuild with gcc 5.2.1

* Tue Aug 18 2015 tmb <tmb> 1:2.25.1-2.mga6
+ Revision: 865415
- rebuild with new glibc

* Sun Aug 02 2015 tmb <tmb> 1:2.25.1-1.mga6
+ Revision: 860852
- push to /release

* Fri Jul 31 2015 tmb <tmb> 1:2.25.1-0.1.mga6
+ Revision: 859934
- rebase linux32 patch
- drop merged / obsolete patches
- resync current fedora patches
- update to 2.25.1

* Wed Jan 14 2015 cjw <cjw> 1:2.24-12.mga5
+ Revision: 810639
- patch105: fix for CVE-2014-8738 (mga #15022)

* Thu Dec 04 2014 cjw <cjw> 1:2.24-11.mga5
+ Revision: 801533
- add more patches from fedora:
  + patch20: Fix decoding of abbrevs using a DW_FORM_ref_addr attribute.
  + patch21: Fix detection of uncompressed .debug_str sections.
  + patch22: Default to -ffat-lto-objects for some ld tests, which was the default in gcc 4.8, but changed in 4.9, and resulted in some failures.
  + patch23: Scan all input files for symbol reference warning.
  + patch26: Backport of fix from HEAD that fixes LTO + ifunc when using ld.bfd instead of gold.
  + patch27: Fix reading of corrupt ELF binaries.
  + patch28: Default strings command to using -a.
  + patch29: Fix problems with the ar program reported in FSF PR 17533.
- patch53: fix ar segfaulting on --plugin, caused by patch16
- patch104: fix compilation with gcc 4.9 and -Werror
- fix patch51 for -Werror
- don't disable -Werror

* Wed Oct 15 2014 umeabot <umeabot> 1:2.24-10.mga5
+ Revision: 743839
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1:2.24-9.mga5
+ Revision: 693506
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1:2.24-8.mga5
+ Revision: 678155
- Mageia 5 Mass Rebuild

* Thu Sep 11 2014 tmb <tmb> 1:2.24-7.mga5
+ Revision: 674672
- rebuild with new glibc and gcc

* Sun Jun 29 2014 tmb <tmb> 1:2.24-6.mga5
+ Revision: 640988
- x86_64.cc (Target_x86_64::Relocate::relocate): Add missing break
- Fix buffer underrun in i386-dis.c

* Tue May 13 2014 tmb <tmb> 1:2.24-5.mga5
+ Revision: 622526
- rebuild with gcc 4.9

* Mon Feb 17 2014 tmb <tmb> 1:2.24-4.mga5
+ Revision: 593944
- rebuild with new glibc

* Sun Jan 05 2014 tmb <tmb> 1:2.24-3.mga4
+ Revision: 564777
- bfd/elflink: Correct elf_merge_st_other arguments for weak symbols

* Sat Dec 14 2013 tmb <tmb> 1:2.24-2.mga4
+ Revision: 556837
- Fix --as-needed undefined symbol references from dynamic libraries

* Wed Dec 04 2013 tmb <tmb> 1:2.24-1.mga4
+ Revision: 555184
- update to 2.24 final

* Tue Oct 22 2013 umeabot <umeabot> 1:2.24-0.20131016.2.mga4
+ Revision: 545616
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 tmb <tmb> 1:2.24-0.20131016.1.mga4
+ Revision: 501464
- update to 2013-10-16 snapshot

* Sat Oct 12 2013 tmb <tmb> 1:2.24-0.20131012.1.mga4
+ Revision: 495973
- update to 2013-10-12 git checkout
- drop merged/obsolete patches
- update to 2.24 (checkout 2013-10-11)

* Sun Aug 11 2013 tmb <tmb> 1:2.23.2-2.mga4
+ Revision: 465387
- rebuild with new gcc

* Sun Aug 11 2013 tmb <tmb> 1:2.23.2-1.mga4
+ Revision: 465372
- push to /release

* Thu Aug 01 2013 tmb <tmb> 1:2.23.2-0.3.mga4
+ Revision: 462059
- rebuild with gcc-4.8.2

* Sun Jul 28 2013 tmb <tmb> 1:2.23.2-0.2.mga4
+ Revision: 459704
- sync patches with fedora
- renumber mga patches
- sync patches to apply cleanly
- fix tarball name
- use https in bugurl
- drop redundant obsoletes
- drop redundant requires
- drop obsolete conflicts
- switch back to official stable FSF binutils 2.23.2 (like Fedora)
  (reasoning: current kernel binutils is too unstable and has too
   many controversial patches)

* Sun Apr 07 2013 rtp <rtp> 2.23.51.0.8-3.mga3
+ Revision: 408971
- disable again tests as the source is still the same
- backport PR/14887 fix.
+ tmb <tmb>
- re-enable checks

* Wed Jan 09 2013 tmb <tmb> 2.23.51.0.8-2.mga3
+ Revision: 344128
- temporarily ignore 3 failing tests like fedora
- fix -set-long-long and -commit-h-check patches not applied due to renumbering in commit 284621
- rediff P8 (-relro by default)
- update to 2.23.51.0.8
- drop P11 (not applied, merged upstream long time ago)
- update bugurl
- update filelists
- sync P2 with fedora
- update to 2.23.51.0.5
- update to 2.23.51.0.3
- rebuild with new gcc

* Mon Aug 27 2012 tv <tv> 2.23.51.0.1-5.mga3
+ Revision: 284622
- new release (improved dwz support for valgrind)
- resync patches with FC
- rediff patch 21

* Wed Jul 18 2012 tmb <tmb> 2.22-5.mga3
+ Revision: 272351
- rebuild for new glibc

* Wed Jun 27 2012 tmb <tmb> 2.22-4.mga3
+ Revision: 264207
- rebuild with gcc-4.7.1

* Sat Mar 03 2012 tmb <tmb> 2.22-3.mga2
+ Revision: 217205
- rebuild with new gcc

* Tue Dec 06 2011 fwang <fwang> 2.22-2.mga2
+ Revision: 177220
- rebuild for new gcc

* Mon Nov 28 2011 rtp <rtp> 2.22-1.mga2
+ Revision: 173834
- Update to binutils 2.22. Test suite clean on 32/64 and nearly clean on arm
  (but still less failures than previous version)
- rediff patch21

* Mon Jun 27 2011 rtp <rtp> 2.21.52.0.1-1.mga2
+ Revision: 114591
- update to 2.21.52.0.1
- drop merged patches
- rediff linux32, build-id, skip-gold-check patches
- drop mips ihex patch. Was not used (even at mdv), so no need to keep
  it forever
- drop ld-selective45-x86_64-xfail as it's no more needed

* Mon Mar 21 2011 rtp <rtp> 2.20.51.0.11-2.mga1
+ Revision: 75232
- fix bug url
- drop old mips patches
- backport PR/12339
- revert isarch to "old" version to get working macros like %%arm %%mips working
- change a ifarch to a if isarch
- add missing if isarch.

* Tue Jan 11 2011 pterjan <pterjan> 2.20.51.0.11-1.mga1
+ Revision: 6171
- Do not use manbo tag
+ blino <blino>
- imported package binutils


* Mon Sep 27 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.20.51.0.11-1mnb2
+ Revision: 581171
- don't include in 'check' target (P27), require all other tests but gold to pass
- allow ld selective[45] tests to fail on x86_64 (P26)
- sync with 2.20.51.0.11-1 from fedora

* Wed Aug 11 2010 Pascal Terjan <pterjan@mandriva.org> 2.20.51.0.7-4mnb2
+ Revision: 569137
- Fix linking to bfd

  + Christophe Fergeau <cfergeau@mandriva.com>
    - remove ugly hack now that binutils rebuilt with the right default linker

* Tue Apr 27 2010 Pascal Terjan <pterjan@mandriva.org> 2.20.51.0.7-3mnb2
+ Revision: 539886
- Ugly workaround to build when gold is default

  + Christophe Fergeau <cfergeau@mandriva.com>
    - don't use gold by default

* Tue Apr 27 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.20.51.0.7-1mnb2
+ Revision: 539422
- be lazy and don't bail out on test failures (due to gold test suite headaches)
- sync with 2.20.51.0.7-2 from fedora

* Mon Dec 28 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.20.51.0.4-2mnb2
+ Revision: 483152
- Fix build with targets which don't have/enable gold.
- Fix build when making cross-* binutils (explicit setup -n to rpmbuild)
- Ship ldscripts with cross-* binutils, some targets need it (like avr).

* Mon Dec 28 2009 Pascal Terjan <pterjan@mandriva.org> 2.20.51.0.4-1mnb2
+ Revision: 483127
- from Frederik Himpe
 o Update to new version 2.20.51.0.4 (fixes statically linking with STT_GNU_IFUNC symbols)
 o Sync patches with Fedora
 o Remove patches integrated upstream
 o Use %%configure2_5x macro instead of %%configure to fix warning when running ./configure

* Fri Nov 27 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.20.51-3mnb2
+ Revision: 470603
- try work around build issues with gold on the BS by doing make again with just
  one job when build fails
- don't explicitly link against libc in linker script, it's implied by libz
- fix multilib conflict in bfd.h header rather than using multiarch
- add a linker script to cure any remaining issues with linking against libbfd

* Wed Nov 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.20.51-2mnb2
+ Revision: 470096
- clear LDFLAGS when building test suite, otherwise some tests will fail
- skip tls_shared_gnu2_test that's known to fail (P28)
- add libstdc++-static-devel to buildrequires as it's required gold's test suite
- be sure to disable -Werror for main binaries as well
- add missing libdl dependency required by 'incremental_dump' (P27)
- add missing 'bfd_plugin_bfd_copy_link_hash_symbol_type' define (P26)
- enable plugins support
- enable gold in parallel with bfd linker (P40)

* Wed Nov 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.20.51-1mnb2
+ Revision: 470017
- for teuf: 2.20.51 ;)
- regenerate patches
- specify http://qa.mandriva.com/ as url for bug reports

* Wed Nov 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.51.0.14-5mnb2
+ Revision: 469897
- add dependency on zlib-devel for devel package

* Tue Nov 24 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.51.0.14-4mnb2
+ Revision: 469861
- build with -fPIC to allow shared libraries to statically link against libbfd.a

* Tue Nov 24 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.51.0.14-3mnb2
+ Revision: 469810
- add back and fix x86 part of linux32 patch that were silently dropped previously

* Tue Nov 24 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.51.0.14-2mnb2
+ Revision: 469709
- don't override %%setup default directory
- fix headers being included more than once
- drop library package due to lack of stable ABI and drop .so symlinks to prevent
  dynamic linking/enforce static linking
- drop conditional scriptlet, we're never gonna backport binutils anyways...
- drop useless README
- disable -Werror through configure option rather than passing -Wno-error ourself

* Mon Nov 23 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.51.0.14-1mnb2
+ Revision: 469382
- use multiarch to avoid conflict between 32 & 64 bit -devel packages (#55831)
- sync with binutils-2.19.51.0.14-34.fc12
- regenerate Mandriva patches (from Matthew Dawkins / Unity Linux)
- don't ship with PIC libiberty for mips..
- add missing 'OPTION_FIX_GS2F_KERNEL' enum type in binutils-2.19.51.0.2-mips-ls2f_fetch_fix.patch

* Wed Feb 11 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.51.0.2-1mnb2
+ Revision: 339335
- apply mips patches from 2008.1 Gdium tree
- enable 64 bit support for mipsel
- new release: 2.19.51.0.2
- spec cosmetics
- remove locale files when doing cross build
- fix string literal errors when building binutils for mips

* Wed Dec 24 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.19.50.0.1-1mnb2
+ Revision: 318384
- fix buildrequires
- sync with 2.19.50.0.1-8.fc11
- new release
- sync with binutils-2.18.50.0.9-1.fc10

* Mon Aug 18 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.18.50.0.8-1mnb2
+ Revision: 273254
- new release
- sync with binutils-2.18.50.0.8-2.fc10

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun May 25 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.18.50.0.6-1mnb2
+ Revision: 211109
- Updated to version 2.18.50.0.6
- Changed license tag (GPL -> GPLv3+, following policy).
- Sync patches with Fedora.

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 2.18.50.0.3-1mnb1
+ Revision: 170649
- replace %%mkrel with %%manbo_mkrel for Manbo Core 1

* Thu Jan 31 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.18.50.0.3-1mdv2008.1
+ Revision: 160824
- New release: 2.18.50.3
- sync patches with Fedora
- regenerate P21 (linux32)
- don't hardcode vendor name & os in target
- add translations
- cosmetics
- add missing ia64 patch from fedora
- sync with fedora 2.17.50.0.12-4
- move checks to %%check
- s/mandrake/mandriva/

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request
    - kill file require on info-install

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Pixel <pixel@mandriva.com>
    - fix group (#28151)

* Sun May 06 2007 Christiaan Welvaart <spturtle@mandriva.org> 2.17.50.0.9-2mdv2008.0
+ Revision: 23749
- match all sparc flavors when checking target_cpu
- fix check to build alternate binaries for spu


* Tue Jan 09 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.17.50.0.9-1mdv2007.0
+ Revision: 106684
- 2.17.50.0.9
- add embedspu to combine spu objects into normal executables for cell

* Wed Jan 03 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.17.50.0.8-1mdv2007.1
+ Revision: 103768
- 2.17.50.0.8
- fix gas error on valid-code complaining about missing .cfi_endproc (BZ#3607)
- re-organise generation of cross binutils, enable make check for cross tools
- move cell spu bits to a specific sub package, don't build spu for cross ppc

* Tue Dec 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.7-6mdv2007.1
+ Revision: 99715
- integrate binart spu_ovl.o for bootstrap
- backport Cell SPU support
- reorganize targets selection, drop support for mach-o objects
- backport DT_GNU_HASH support
- make linux32 as generate 32-bit code on ppc64
- bunzip2 patches
- Import binutils

* Wed Oct 25 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.7-5mdv
- improve biarch x86-linux support (64-bit on 32-bit)
- update to upstream cell patch (new AltiVec instructions)

* Fri Sep 22 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.7-4mdv
- add cell ppu support

* Wed Aug 30 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.7-3mdv2007.0
- CVE-2006-2362 (PR binutils/2584)

* Fri Jul 21 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.7-2mdk
- build with -Wno-error
- more libtool fixes for build
- selected fixes from CVS:
  * add "nop memory" for i386/x86-64
  * fix x86-64 disassembler for sidt/sgdt
  * fix a visibility bug in ELF linker (PR 2884)

* Fri May 12 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.7-1mdk
- 2.16.91.0.7
- fix build with gcc4.1

* Fri May 12 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.6-2mdk
- avoid abort with dynamic symbols in >64K sections (PR 2411)
- merge with RH 2.16.91.0.6-6
  * support S signal frame augmentation flag in .eh_frame,
    add .cfi_signal_frame support (#175951, PR other/26208, BZ#300)
  * support DW_CFA_val_{offset,offset_sf,expression} in readelf/objdump
  * fix relaxation of TLS GD to LE on PPC (RH #184590)
  * fix for g++ -frepo ((RH #187142)

* Tue Mar 07 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.6-1mdk
- 2.16.91.0.6
- fix PR ld/2218 (H.J. Lu)
- add Merom New Instructions (MNI)

* Sat Aug 13 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.2-3mdk
- fix requires for install-info

* Fri Aug 05 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.2-2mdk
- remove obsolete patch that was fixed in a previous snapshot
- make the linker ignore .got2 relocs against symbols from discarded
  sections (Alan Modra, PR target/17828)

* Sat Jul 23 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.2-1mdk
- 2.16.91.0.2:
  * update from binutils 2005 0720
  * add AMD SVME & Intel VMX support
  * add x86-64 new relocations for medium model
  * fix a PIE regression (PR 975)
  * fix an x86_64 signed 32bit displacement regression
  * fix PPC PLT (PR 1004)
  * imrove empty section removal

* Fri Jul 08 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.91.0.1-1mdk
- 2.16.91.0.1

* Thu Jun 16 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.3-2mdk
- all tests pass on ppc64 too
- build sparc with --enable-64-bit-bfd (peroyvind)

* Wed May 18 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.3-1mdk
- 2.16.90.0.3

* Sat May 07 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.2-3mdk
- enable 64-bit targets for ppc and sparc

* Thu May 05 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.2-2mdk
- selected fix from CVS to fix kdebase build:
  * skip weak definitions if a strong definition has already been seen

* Sun May 01 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.2-1mdk
- 2.16.90.0.2
- fix ld -pie

* Wed Apr 27 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.1-2mdk
- Selected fixes from mainline CVS to fix --as-needed and PR ld/815

* Tue Apr 26 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.16.90.0.1-1mdk
- 2.16.90.0.1

* Tue Mar 08 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.92.0.2-6mdk
- don't build shared libraries for cross binutils

* Tue Feb 01 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.92.0.2-5mdk
- handle protected functions correctly on x86_64 (PR binutils/584, H. J. Lu)

* Tue Jan 18 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.92.0.2-4mdk
- make "as" aware of its current personality on x86-64 so that 32-bit
  object can be generated by default (if running under linux32)

* Thu Dec 16 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.92.0.2-3mdk
- fix build on x86_64

* Wed Nov 24 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.92.0.2-2mdk
- Further merge with RH 2.15.92.0.2-6
  * revert Sep 09 change to make ppc L second argument e.g. for tlbie non-optional
  * fix --just-symbols on ppc64 (Alan Modra, #135498)
  * fix -pie on ppc64

* Wed Nov 10 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.92.0.2-1mdk
- Merge with RH 2.15.92.0.2-6
  * fix ar xo
  * fix stripping of prelinked binaries and libraries
  * allow strings(1) on 32-bit arches to be used again with > 2GB files
  * fix code detecting matching linkonce and single member comdat group sections
  * fix -z relro to make sure end of PT_GNU_RELRO segment is always COMMONPAGESIZE aligned
  * fix orphan section placement
  * change ld's ld.so.conf parser to match ldconfig's

* Wed May 12 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.15.90.0.3-1mdk
- 2.15.90.0.3
- change x86-64 .plt symbol st_size handling to match ia32 (RH 2.15.90.0.3-4)

* Mon Jan 12 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.14.90.0.7-2mdk
- Fix cross binutils builds with newer rpm
- Enable Mach-O and PEF targets on cross PowerPC binutils

